@@ -25,12 +25,18 @@
 
 #include <glib.h>
 
-#include <gtk/gtktreemodel.h>
+#include <gtk/gtk.h>
 #include "totem-pl-parser-features.h"
 #include "totem-pl-parser-builtins.h"
 
 G_BEGIN_DECLS
 
+/* Compatibility defines */
+#define TOTEM_PL_PARSER_FIELD_URL		TOTEM_PL_PARSER_FIELD_URI
+#define TOTEM_PL_PARSER_FIELD_IMAGE_URL		TOTEM_PL_PARSER_FIELD_IMAGE_URI
+#define TOTEM_PL_PARSER_FIELD_DOWNLOAD_URL	TOTEM_PL_PARSER_FIELD_DOWNLOAD_URI
+/* End */
+
 #define TOTEM_TYPE_PL_PARSER            (totem_pl_parser_get_type ())
 #define TOTEM_PL_PARSER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TOTEM_TYPE_PL_PARSER, TotemPlParser))
 #define TOTEM_PL_PARSER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TOTEM_TYPE_PL_PARSER, TotemPlParserClass))
@@ -71,11 +77,11 @@ struct TotemPlParser {
 /* Known metadata fields */
 
 /**
- * TOTEM_PL_PARSER_FIELD_URL:
+ * TOTEM_PL_PARSER_FIELD_URI:
  *
- * Metadata field for an entry's URL.
+ * Metadata field for an entry's URI.
  **/
-#define TOTEM_PL_PARSER_FIELD_URL		"url"
+#define TOTEM_PL_PARSER_FIELD_URI		"url"
 /**
  * TOTEM_PL_PARSER_FIELD_GENRE:
  *
@@ -171,7 +177,7 @@ struct TotemPlParser {
 /**
  * TOTEM_PL_PARSER_FIELD_MOREINFO:
  *
- * Metadata field for an entry's "more info" URL.
+ * Metadata field for an entry's "more info" URI.
  **/
 #define TOTEM_PL_PARSER_FIELD_MOREINFO		"moreinfo"
 /**
@@ -211,18 +217,18 @@ struct TotemPlParser {
  **/
 #define TOTEM_PL_PARSER_FIELD_CONTACT		"contact"
 /**
- * TOTEM_PL_PARSER_FIELD_IMAGE_URL:
+ * TOTEM_PL_PARSER_FIELD_IMAGE_URI:
  *
- * Metadata field for an entry's thumbnail image URL.
+ * Metadata field for an entry's thumbnail image URI.
  **/
-#define TOTEM_PL_PARSER_FIELD_IMAGE_URL		"image-url"
+#define TOTEM_PL_PARSER_FIELD_IMAGE_URI		"image-url"
 /**
- * TOTEM_PL_PARSER_FIELD_DOWNLOAD_URL:
+ * TOTEM_PL_PARSER_FIELD_DOWNLOAD_URI:
  *
- * Metadata field for an entry's download URL. Only used if an alternate download
+ * Metadata field for an entry's download URI. Only used if an alternate download
  * location is available for the entry.
  **/
-#define TOTEM_PL_PARSER_FIELD_DOWNLOAD_URL	"download-url"
+#define TOTEM_PL_PARSER_FIELD_DOWNLOAD_URI	"download-url"
 /**
  * TOTEM_PL_PARSER_FIELD_ID:
  *
@@ -286,16 +292,16 @@ typedef enum
 
 /**
  * TotemPlParserError:
- * @TOTEM_PL_PARSER_ERROR_VFS_OPEN: Error on opening a file
- * @TOTEM_PL_PARSER_ERROR_VFS_WRITE: Error on writing a file
+ * @TOTEM_PL_PARSER_ERROR_NO_DISC: Error attempting to open a disc device when no disc is present
+ * @TOTEM_PL_PARSER_ERROR_MOUNT_FAILED: An attempted mount operation failed
  *
  * Allows you to differentiate between different
  * errors occurring during file operations in a #TotemPlParser.
  **/
 typedef enum
 {
-	TOTEM_PL_PARSER_ERROR_VFS_OPEN,
-	TOTEM_PL_PARSER_ERROR_VFS_WRITE,
+	TOTEM_PL_PARSER_ERROR_NO_DISC,
+	TOTEM_PL_PARSER_ERROR_MOUNT_FAILED
 } TotemPlParserError;
 
 #define TOTEM_PL_PARSER_ERROR (totem_pl_parser_error_quark ())
@@ -348,14 +354,17 @@ void       totem_pl_parser_add_ignored_mimetype (TotemPlParser *parser,
 						 const char *mimetype);
 
 TotemPlParserResult totem_pl_parser_parse (TotemPlParser *parser,
-					   const char *url, gboolean fallback);
+					   const char *uri, gboolean fallback);
 TotemPlParserResult totem_pl_parser_parse_with_base (TotemPlParser *parser,
-						     const char *url,
+						     const char *uri,
 						     const char *base,
 						     gboolean fallback);
 
 TotemPlParser *totem_pl_parser_new (void);
 
+GType totem_pl_parser_metadata_get_type (void) G_GNUC_CONST;
+#define TOTEM_TYPE_PL_PARSER_METADATA (totem_pl_parser_metadata_get_type())
+
 G_END_DECLS
 
 #endif /* TOTEM_PL_PARSER_H */
